@@ -1,9 +1,8 @@
 """
-__init__.py
+Timeplus Python SDK provide API access to Timeplus's core resoruces including `Stream`, `Query`, `Source` and `Sink`
 
-This module export timeplus functions and classes.
-:copyright: (c) 2022 by Timeplus
-:license: Apache2, see LICENSE for more details.
+
+.. include:: ./documentation.md
 """
 
 from .version import __version__  # noqa: F401
@@ -25,6 +24,4 @@ from timeplus.sink import Sink  # noqa: F401
 from timeplus.slack import SlackSink, SlackSinkProperty  # noqa: F401
 from timeplus.smtp import SMTPSink, SMTPSinkProperty  # noqa: F401
 from timeplus.stream import Stream, StreamColumn  # noqa: F401
-from timeplus.alert import Alert  # noqa: F401
-from timeplus.saved_query import SavedQuery  # noqa: F401
 from timeplus.type import Type  # noqa: F401
