@@ -43,6 +43,8 @@ class Env(Base):
         self.schema("http")
         self.api_version("api/v1beta1")
         self.token("")
+        self.api_key_id("")
+        self.api_key("")
         self.domain = "timeplus.us.auth0.com"
         self._max_token_refresh = 24
         self._token_refresh = 0
@@ -105,9 +107,11 @@ class Env(Base):
         return f"{self.schema()}://{self.host()}:{self.port()}/{self.api_version()}"
 
     def headers(self):
-        self._headers["Authorization"] = f"Bearer {self.token()}"
-        self._headers["X-Api-Key-Id"] = self.api_key_id()
-        self._headers["X-Api-Key"] = self.api_key()
+        if self.api_key_id() and self.api_key():  # check if key and id are not empty
+            self._headers["X-Api-Key-Id"] = self.api_key_id()
+            self._headers["X-Api-Key"] = self.api_key()
+        else:
+            self._headers["Authorization"] = f"Bearer {self.token()}"
         return self._headers
 
     def token(self, *args):
